@@ -1,7 +1,6 @@
 use Dash;
-use aliased 'Dash::Html::Components::Div';
-use aliased 'Dash::Html::Components::H1';
-use aliased 'Dash::Core::Components::Input';
+use aliased 'Dash::Html::Components' => 'html';
+use aliased 'Dash::Core::Components' => 'dcc';
 
 my $external_stylesheets = ['https://codepen.io/chriddyp/pen/bWLwgP.css'];
 
@@ -11,10 +10,9 @@ my $app = Dash->new(
 );
 
 $app->layout(
-    Div->new(children => [
-        H1->new(children => 'Titulo'),
-        Input->new(id => 'my-id', value => 'initial value', type => 'text'),
-        Div->new(id => 'my-div')
+    html->Div([
+        dcc->Input(id => 'my-id', value => 'initial value', type => 'text'),
+        html->Div(id => 'my-div')
     ])
 );
 
@@ -23,7 +21,7 @@ $app->callback(
     Inputs => [{component_id=>'my-id', component_property=> 'value'}],
     callback => sub {
         my $input_value = shift;
-        return "You've entered \"$input_value\"";
+        return "You've entered '$input_value'";
     }
 );
 
