@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.020;
 
-our $VERSION = '0.08';    # VERSION
+our $VERSION = '0.09';    # VERSION
 
 # ABSTRACT: Analytical Web Apps in Perl (Port of Plotly's Dash to Perl)
 
@@ -313,12 +313,14 @@ sub _update_component {
         } elsif ( scalar @$callbacks == 1 ) {
             my $callback           = $callbacks->[0];
             my @callback_arguments = ();
+            my $callback_context   = {};
             for my $callback_input ( @{ $callback->{Inputs} } ) {
                 my ( $component_id, $component_property ) = @{$callback_input}{qw(component_id component_property)};
                 for my $change_input ( @{ $request->{inputs} } ) {
                     my ( $id, $property, $value ) = @{$change_input}{qw(id property value)};
                     if ( $component_id eq $id && $component_property eq $property ) {
                         push @callback_arguments, $value;
+                        $callback_context->{inputs}{ $id . "." . $property } = $value;
                         last;
                     }
                 }
@@ -329,10 +331,21 @@ sub _update_component {
                     my ( $id, $property, $value ) = @{$change_input}{qw(id property value)};
                     if ( $component_id eq $id && $component_property eq $property ) {
                         push @callback_arguments, $value;
+                        $callback_context->{states}{ $id . "." . $property } = $value;
                         last;
                     }
                 }
             }
+
+            $callback_context->{triggered} = [];
+            for my $triggered_input ( @{ $request->{changedPropIds} } ) {
+                push @{ $callback_context->{triggered} },
+                  { prop_id => $triggered_input,
+                    value   => $callback_context->{inputs}{$triggered_input}
+                  };
+            }
+            push @callback_arguments, $callback_context;
+
             my $output_type = ref $callback->{Output};
             if ( $output_type eq 'ARRAY' ) {
                 my @return_value  = $callback->{callback}(@callback_arguments);
@@ -602,7 +615,7 @@ Dash - Analytical Web Apps in Perl (Port of Plotly's Dash to Perl)
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -696,6 +709,8 @@ minor changes:
 
 =item * Instead of decorators we'll use plain old callbacks
 
+=item * Callback context is available as the last parameter of the callback but without the response part
+
 =item * Instead of Flask we'll be using L<Mojolicious> (Maybe in the future L<Dancer2>)
 
 =back
@@ -793,8 +808,6 @@ Right now there are a lot of parts missing:
 
 =over 4
 
-=item * Callback context
-
 =item * Prefix mount
 
 =item * Debug mode & hot reloading
